@@ -55,11 +55,13 @@ var group__pw__filter =
     [ "pw_filter_update_params", "group__pw__filter.html#gaee14b619b5b412e439eba180798f5300", null ],
     [ "pw_filter_get_time", "group__pw__filter.html#gac5ba311e3a8df6fe521d9b9f2a825ec7", null ],
     [ "pw_filter_get_nsec", "group__pw__filter.html#ga6cf6adb8d161be530bbbd64c5132b052", null ],
+    [ "pw_filter_get_data_loop", "group__pw__filter.html#gaaa7530264cc2ab3c24715f9b3ca54d2a", null ],
     [ "pw_filter_dequeue_buffer", "group__pw__filter.html#gad2c604e7809ab43e7731a3b47cddcbb0", null ],
     [ "pw_filter_queue_buffer", "group__pw__filter.html#ga67e9ec5afe20ab5c4c08bc92dcaa21a2", null ],
     [ "pw_filter_get_dsp_buffer", "group__pw__filter.html#gaf86eb47b3adbca1ddfb66235a8a5ae69", null ],
     [ "pw_filter_set_active", "group__pw__filter.html#gaa9ae747610cbf4c82d332b2c2a76b589", null ],
     [ "pw_filter_flush", "group__pw__filter.html#gae17ab8123b31539b441c263fd54ad7bb", null ],
     [ "pw_filter_is_driving", "group__pw__filter.html#gad656221f69c629c9b4ef5771ce7c2be8", null ],
+    [ "pw_filter_is_lazy", "group__pw__filter.html#gad9fdedf3a1c65c851bdee7dd023837b4", null ],
     [ "pw_filter_trigger_process", "group__pw__filter.html#ga7d90afb148ba4591498e62abf2df2665", null ]
 ];
\ No newline at end of file
