@@ -1,5 +1,10 @@
 var NAVTREEINDEX16 =
 {
+"page_man_pw-mon_1.html":[2,13],
+"page_man_pw-profiler_1.html":[2,14],
+"page_man_pw-reserve_1.html":[2,15],
+"page_man_pw-top_1.html":[2,16],
+"page_man_pw-v4l2_1.html":[2,17],
 "page_man_spa-acp-tool_1.html":[2,18],
 "page_man_spa-inspect_1.html":[2,19],
 "page_man_spa-json-dump_1.html":[2,20],
@@ -244,10 +249,5 @@ var NAVTREEINDEX16 =
 "structpw__client__endpoint.html":[8,6,4,22],
 "structpw__client__endpoint__events.html":[8,6,4,6],
 "structpw__client__endpoint__events.html#a02d8f4d9cd9f898d3109a64f7afd81e1":[8,6,4,6,4],
-"structpw__client__endpoint__events.html#a12f427748eebbfd39cdc4f75a9db57ed":[8,6,4,6,1],
-"structpw__client__endpoint__events.html#a43e06e14ba4461922bfce4c3c98c13f1":[8,6,4,6,3],
-"structpw__client__endpoint__events.html#a45e7bb70eb2b24c33aad0c82dcf001b6":[8,6,4,6,2],
-"structpw__client__endpoint__events.html#afab781a09b218afdc2c9ffb54502be5e":[8,6,4,6,0],
-"structpw__client__endpoint__methods.html":[8,6,4,7],
-"structpw__client__endpoint__methods.html#a283f6ec14d1a3ff9b0b0aa213b2ea850":[8,6,4,7,1]
+"structpw__client__endpoint__events.html#a12f427748eebbfd39cdc4f75a9db57ed":[8,6,4,6,1]
 };
