@@ -1,5 +1,15 @@
 var NAVTREEINDEX20 =
 {
+"structspa__dbus__connection__events.html#a2ae8b95b36226127853160f1779260e0":[8,7,9,1,2,0],
+"structspa__dbus__connection__events.html#a481b39049a46ec7d8519c8d2c9318968":[8,7,9,1,2,2],
+"structspa__dbus__methods.html":[8,7,9,1,4],
+"structspa__dbus__methods.html#a1e518bcb13046ec6b46a927024b6cc28":[8,7,9,1,4,1],
+"structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434":[8,7,9,1,4,0],
+"structspa__debug__context.html":[8,7,3,10],
+"structspa__debug__context.html#af9f0b4808459f1701213a4dbac14601f":[8,7,3,10,0],
+"structspa__debug__file__ctx.html":[8,7,3,11],
+"structspa__debug__file__ctx.html#a34708c6380f0ca51b9d318a089306401":[8,7,3,11,1],
+"structspa__debug__file__ctx.html#a817d19045e3261030ec8e38842a018c3":[8,7,3,11,0],
 "structspa__debug__log__ctx.html":[8,7,3,12],
 "structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724":[8,7,3,12,6],
 "structspa__debug__log__ctx.html#a49ae612d5a9f8abff00d338e0f42f338":[8,7,3,12,5],
@@ -239,15 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__log__topic.html":[8,7,9,3,3],
 "structspa__log__topic.html#a03003ed60b6acc4788b41e74b9945911":[8,7,9,3,3,0],
 "structspa__log__topic.html#a1295d4049013c031f7c30074182dfe58":[8,7,9,3,3,3],
-"structspa__log__topic.html#a23fb58684c75ff5cadeda72fa6ea1f92":[8,7,9,3,3,2],
-"structspa__log__topic.html#ab77cbaf7b01d2f4dddbcf7f51766b9d6":[8,7,9,3,3,1],
-"structspa__log__topic__enum.html":[8,7,9,3,4],
-"structspa__log__topic__enum.html#a3306c265f098ac2ccf248c9977c1cc9e":[8,7,9,3,4,2],
-"structspa__log__topic__enum.html#ab100eb5174eac7bbb5fb2766f569bab4":[8,7,9,3,4,1],
-"structspa__log__topic__enum.html#acc701c2634125be347e22fd995a4e08c":[8,7,9,3,4,0],
-"structspa__loop.html":[8,7,9,4,1],
-"structspa__loop.html#a6cd472082b361bc90f66c41b0dccea96":[8,7,9,4,1,0],
-"structspa__loop__control.html":[8,7,9,4,2],
-"structspa__loop__control.html#a392f811fbacb15de863fc0265031050f":[8,7,9,4,2,0],
-"structspa__loop__control__hooks.html":[8,7,9,4,6]
+"structspa__log__topic.html#a23fb58684c75ff5cadeda72fa6ea1f92":[8,7,9,3,3,2]
 };
