@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"group__spa__device.html#ga5fc03e022b6b34a95c40b992b46210b3":[8,7,4,57],
+"group__spa__device.html#ga64af18e863a2a13cfe4e9ac71adb5b20":[8,7,4,33],
+"group__spa__device.html#ga6573dc405f256f96d9ec6b6518c5c6d8":[8,7,4,74],
+"group__spa__device.html#ga65e21b7134e493124a67e4c582564c29":[8,7,4,71],
 "group__spa__device.html#ga6d0493b863780697cf564ff4ae297191":[8,7,4,81],
 "group__spa__device.html#ga725ef202231224d45f0297aa2c6e84f1":[8,7,4,59],
 "group__spa__device.html#ga756d90f78ac51e42bcfd0405b40e2fb9":[8,7,4,77],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__keys.html#gacbd114ae1cc6ad79d065292e645f8d44":[8,7,8,8,5],
 "group__spa__keys.html#gad11f51a8eaa7f2f2eea0074b5633f402":[8,7,8,8,7],
 "group__spa__keys.html#gad13b0f3fd7970f7bb1332782ff8d649e":[8,7,8,8,10],
-"group__spa__keys.html#gad3ec15b6e5bbdd02f195a2356f2282de":[8,7,8,8,37],
-"group__spa__keys.html#gadf50fc8fd87773ea21c53db357e38ae6":[8,7,8,8,58],
-"group__spa__keys.html#gae257876566997855b6cc94aa12c60d85":[8,7,8,8,14],
-"group__spa__keys.html#gae40f1dac2ce129ce24536b84f18464a6":[8,7,8,8,55],
-"group__spa__keys.html#gae6934f93ea5aaa60d2136f0d9af5ad47":[8,7,8,8,23]
+"group__spa__keys.html#gad3ec15b6e5bbdd02f195a2356f2282de":[8,7,8,8,37]
 };
