@@ -18,14 +18,16 @@ var searchData=
   ['get_5fsize_15',['get_size',['../structspa__handle__factory.html#aa48d0b857861f618011a9f4a89435484',1,'spa_handle_factory']]],
   ['get_5fvm_5ftype_16',['get_vm_type',['../structspa__cpu__methods.html#acd636f83ca2db246adfc92fc7d669204',1,'spa_cpu_methods']]],
   ['getting_20started_17',['Tutorial - Part 1: Getting Started',['../page_tutorial1.html',1,'page_tutorial']]],
-  ['global_18',['global',['../structpw__registry__events.html#a37bd7089a7a07d7154e111e67b25f96c',1,'pw_registry_events::global'],['../group__pw__global.html',1,'Global']]],
-  ['global_2eh_19',['global.h',['../global_8h.html',1,'']]],
-  ['global_5fadded_20',['global_added',['../structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d',1,'pw_context_events']]],
-  ['global_5fremove_21',['global_remove',['../structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97',1,'pw_registry_events']]],
-  ['global_5fremoved_22',['global_removed',['../structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0',1,'pw_context_events']]],
-  ['graph_23',['graph',['../structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740',1,'spa_graph_node::graph'],['../group__spa__graph.html',1,'Graph']]],
-  ['graph_20scheduling_24',['Graph Scheduling',['../page_scheduling.html',1,'page_internals']]],
-  ['graph_2eh_25',['graph.h',['../graph_8h.html',1,'']]],
-  ['graph_5flink_26',['graph_link',['../structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0',1,'spa_graph_node']]],
-  ['gsettings_27',['GSettings',['../page_pulse_module_gsettings.html',1,'page_pulse_modules']]]
+  ['global_18',['Global',['../group__pw__global.html',1,'']]],
+  ['global_19',['global',['../structpw__registry__events.html#a37bd7089a7a07d7154e111e67b25f96c',1,'pw_registry_events']]],
+  ['global_2eh_20',['global.h',['../global_8h.html',1,'']]],
+  ['global_5fadded_21',['global_added',['../structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d',1,'pw_context_events']]],
+  ['global_5fremove_22',['global_remove',['../structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97',1,'pw_registry_events']]],
+  ['global_5fremoved_23',['global_removed',['../structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0',1,'pw_context_events']]],
+  ['graph_24',['Graph',['../group__spa__graph.html',1,'']]],
+  ['graph_25',['graph',['../page_streams.html#sec_stream_driving',1,'Driving the graph'],['../structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740',1,'spa_graph_node::graph']]],
+  ['graph_20scheduling_26',['Graph Scheduling',['../page_scheduling.html',1,'page_internals']]],
+  ['graph_2eh_27',['graph.h',['../graph_8h.html',1,'']]],
+  ['graph_5flink_28',['graph_link',['../structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0',1,'spa_graph_node']]],
+  ['gsettings_29',['GSettings',['../page_pulse_module_gsettings.html',1,'page_pulse_modules']]]
 ];
